<?php

/**
  ReduxFramework Sample Config File
  For full documentation, please visit: https://docs.reduxframework.com
 * */
if (!class_exists('VG_Admin_to_Frontend_Redux_Setup')) {

	class VG_Admin_to_Frontend_Redux_Setup {

		public $args = array();
		public $sections = array();
		public $pts;
		public $ReduxFramework;

		public function __construct() {

			if (!class_exists('ReduxFramework')) {
				return;
			}

			// This is needed. Bah WordPress bugs.  ;)
			if (true == Redux_Helpers::isTheme(__FILE__)) {
				$this->initSettings();
			} else {
				add_action('init', array($this, 'initSettings'), 10);
			}
		}

		public function initSettings() {


			// Set the default arguments
			$this->setArguments();


			// Create the sections and fields
			$this->setSections();

			if (!isset($this->args['opt_name'])) { // No errors please
				return;
			}

			// If Redux is running as a plugin, this will remove the demo notice and links
			add_action('redux/loaded', array($this, 'remove_demo'));

			$this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
		}

		// Remove the demo link and the notice of integrated demo from the redux-framework plugin
		function remove_demo() {

			// Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
			if (class_exists('ReduxFrameworkPlugin')) {
				remove_filter('plugin_row_meta', array(ReduxFrameworkPlugin::instance(), 'plugin_metalinks'), null, 2);

				// Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
				remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
			}
		}

		public function setSections() {

			$this->sections[] = array(
				'icon' => 'el-icon-cogs',
				'title' => __('General', VG_Admin_To_Frontend::$textname),
				'fields' => array(
					array(
						'id' => 'login_message',
						'type' => 'editor',
						'title' => __('Login message', VG_Admin_To_Frontend::$textname),
						'default' => __('You need to login to view this page. [vgca_login_page_link].', VG_Admin_To_Frontend::$textname),
						'desc' => __('This will be displayed when the current user is not logged in and tries to see an admin page through a shortcode on the frontend. Use shortcode: [vgca_login_page_link] to return a link to the login page.', VG_Admin_To_Frontend::$textname),
					),
					array(
						'id' => 'admin_view_css',
						'type' => 'textarea',
						'mode' => 'css',
						'title' => __('Admin CSS', VG_Admin_To_Frontend::$textname),
						'desc' => __('This css will be used to customize the admin page when viewing it´s displayed on the frontend. For example, you can hide admin elements or tweak admin design. You dont need to add style tags, just add the plain css.', VG_Admin_To_Frontend::$textname),
					),
					array(
						'id' => 'hide_admin_bar_frontend',
						'type' => 'switch',
						'title' => __('Hide admin bar on the frontend', VG_Admin_To_Frontend::$textname),
						'desc' => __('By default WordPress shows a black bar at the top of the page when a logged in user views a frontend page. The bar lets you access the wp-admin, log out, edit the current page, etc. If you enable this option we will hide that bar and you can use the shortcode: [vg_display_logout_link] to display the logout link.', VG_Admin_To_Frontend::$textname),
						'default' => false,
					)
				),
			);
		}

		/**

		  All the possible arguments for Redux.
		  For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments

		 * */
		public function setArguments() {

			$this->args = array(
				'opt_name' => VG_Admin_To_Frontend::$textname,
				'display_name' => __('Settings', VG_Admin_To_Frontend::$textname),
				'display_version' => VG_Admin_To_Frontend::$version,
				'page_slug' => VG_Admin_To_Frontend::$textname,
				'page_title' => __('Settings', VG_Admin_To_Frontend::$textname),
				'update_notice' => false,
				'admin_bar' => false,
				'menu_type' => 'submenu',
				'menu_title' => __('Settings', VG_Admin_To_Frontend::$textname),
//				'page_parent' => 'options-general.php',
				'page_parent' => 'wpatof_welcome_page',
				'default_mark' => '*',
				'hints' =>
				array(
					'icon' => 'el-icon-question-sign',
					'icon_position' => 'right',
					'icon_color' => 'lightgray',
					'icon_size' => 'normal',
					'tip_style' =>
					array(
						'color' => 'light',
					),
					'tip_position' =>
					array(
						'my' => 'top left',
						'at' => 'bottom right',
					),
					'tip_effect' =>
					array(
						'show' =>
						array(
							'duration' => '500',
							'event' => 'mouseover',
						),
						'hide' =>
						array(
							'duration' => '500',
							'event' => 'mouseleave unfocus',
						),
					),
				),
				'output' => true,
				'output_tag' => true,
				'compiler' => true,
				'page_icon' => 'icon-themes',
				'dev_mode' => false,
				'page_permissions' => 'manage_options',
				'save_defaults' => true,
				'show_import_export' => true,
				'transient_time' => '3600',
				'network_sites' => true,
			);
		}

	}

	add_action('plugins_loaded', 'vgca_init_options_page');

	function vgca_init_options_page() {

		new VG_Admin_to_Frontend_Redux_Setup();
	}

}

/**
 * Disable dev mode. For some reason it doesnt disable when 
 * I change the dev_mode argument when constructing the options page.
 * So I took this code from the redux-developer-mode-disabler plugin
 */
if (!function_exists('vg_redux_disable_dev_mode_plugin')) {

	function vg_redux_disable_dev_mode_plugin($redux) {
		if ($redux->args['opt_name'] != 'redux_demo') {
			$redux->args['dev_mode'] = false;
			$redux->args['forced_dev_mode_off'] = false;
		}
	}

	add_action('redux/construct', 'vg_redux_disable_dev_mode_plugin');
}
