<?php

/*
  Plugin Name: WP Frontend Admin
  Plugin URI: https://wpfrontendadmin.com
  Description: Display wp-admin pages on the frontend using a shortcode.
  Version: 1.3.0
  Author: JoseVega
  Author Email: josevega@wpfrontendadmin.com
  Author URI: https://wpsheeteditor.com
  License:
 Copyright 2018 JoseVega (josevega@vegacorp.me)
 This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.
 This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
require 'inc/freemius-init.php';
require 'vendor/vg-plugin-sdk/index.php';

if ( !class_exists( 'VG_Admin_To_Frontend' ) ) {
    class VG_Admin_To_Frontend
    {
        private static  $instance = false ;
        static  $textname = 'vg_admin_to_frontend' ;
        static  $dir = __DIR__ ;
        static  $version = '1.3.0' ;
        static  $name = 'Frontend Admin' ;
        var  $allowed_urls = array() ;
        var  $base_page_id = 'vgca_base_page_id' ;
        private function __construct()
        {
        }
        
        function get_settings( $key = null, $default = null )
        {
            $options = get_option( VG_Admin_To_Frontend::$textname, array() );
            $out = $options;
            if ( !empty($key) && isset( $options[$key] ) ) {
                $out = $options[$key];
            }
            if ( empty($out) ) {
                $out = $default;
            }
            return $out;
        }
        
        function get_plugin_install_url( $plugin_slug )
        {
            $install_plugin_base_url = ( is_multisite() ? network_admin_url() : admin_url() );
            $install_plugin_url = add_query_arg( array(
                's'    => $plugin_slug,
                'tab'  => 'search',
                'type' => 'term',
            ), $install_plugin_base_url . 'plugin-install.php' );
            return $install_plugin_url;
        }
        
        function init()
        {
            $this->args = array(
                'main_plugin_file'  => __FILE__,
                'show_welcome_page' => true,
                'welcome_page_file' => VG_Admin_To_Frontend::$dir . '/views/welcome-page-content.php',
                'plugin_name'       => VG_Admin_To_Frontend::$name,
                'plugin_prefix'     => 'wpatof_',
                'plugin_version'    => VG_Admin_To_Frontend::$version,
                'plugin_options'    => get_option( VG_Admin_To_Frontend::$textname, false ),
            );
            $this->vg_plugin_sdk = new VG_Freemium_Plugin_SDK( $this->args );
            add_shortcode( 'vg_display_admin_page', array( $this, 'get_admin_page_for_frontend' ) );
            add_shortcode( 'vg_display_logout_link', array( $this, 'get_logout_link' ) );
            add_action( 'admin_head', array( $this, 'cleanup_admin_page_for_frontend' ) );
            add_action( 'admin_menu', array( $this, 'register_menu_page' ) );
            add_action( 'admin_init', array( $this, 'maybe_redirect_direct_link' ) );
            add_action( 'after_setup_theme', array( $this, 'late_init' ) );
            add_action( 'admin_bar_menu', array( $this, 'add_direct_link_menu' ), 999 );
            if ( $this->get_settings( 'hide_admin_bar_frontend' ) && !is_admin() ) {
                add_filter( 'show_admin_bar', '__return_false' );
            }
        }
        
        function get_shortcode_for_slug( $slug )
        {
            return '[vg_display_admin_page page_url="' . $slug . '"]';
        }
        
        function get_page_id( $admin_url, $title )
        {
            global  $wpdb ;
            $shortcode = $this->get_shortcode_for_slug( $admin_url );
            $page_id = (int) $wpdb->get_var( "SELECT ID FROM {$wpdb->posts} WHERE post_type = 'page' AND post_status = 'publish' AND post_content LIKE '%" . esc_sql( $shortcode ) . "%' " );
            if ( !$page_id ) {
                $page_id = wp_insert_post( array(
                    'post_type'    => 'page',
                    'post_status'  => 'publish',
                    'post_title'   => $title,
                    'post_content' => $shortcode,
                ) );
            }
            return $page_id;
        }
        
        /**
         * Redirect from wp-admin url to the real frontend url.
         * We could link to the frontend url directly on the toolbar, but we´re doing this
         * redirect so we create the base page only when needed.
         * 
         * @return null
         */
        function maybe_redirect_direct_link()
        {
            if ( empty($_GET['vgca_direct']) ) {
                return;
            }
            $page_id = $this->get_page_id( esc_url( admin_url( $_GET['vgca_slug'] ) ), sanitize_text_field( $_GET['title'] ) );
            $page_url = get_permalink( $page_id );
            wp_redirect( $page_url );
            exit;
        }
        
        function add_direct_link_menu( $wp_admin_bar )
        {
            $args = array(
                'id'    => 'vgca-direct-frontend-link',
                'title' => __( 'View on the frontend', VG_Admin_To_Frontend::$textname ),
                'href'  => add_query_arg( array(
                'vgca_direct' => 1,
            ), admin_url() ),
                'meta'  => array(
                'class' => 'vgca-direct-frontend-link',
            ),
            );
            $wp_admin_bar->add_node( $args );
        }
        
        function late_init()
        {
            $this->allowed_urls = apply_filters( 'vg_admin_to_frontend/allowed_urls', array(
                admin_url( 'edit.php' ),
                admin_url( 'post-new.php' ),
                admin_url( 'edit-tags.php?taxonomy=post_tag' ),
                admin_url( 'edit-tags.php?taxonomy=category' )
            ) );
        }
        
        function register_menu_page()
        {
            add_menu_page(
                VG_Admin_To_Frontend::$name,
                VG_Admin_To_Frontend::$name,
                'manage_options',
                'wpatof_welcome_page',
                array( $this->vg_plugin_sdk, 'render_welcome_page' )
            );
        }
        
        function cleanup_admin_page_for_frontend()
        {
            $custom_css = preg_replace( '/(\\r|\\n)/', '', $this->get_settings( 'admin_view_css', '' ) );
            ?>
			<style>
				.vgca-only-admin-content body {
					background: transparent;
				}
				.vgca-only-admin-content #wpadminbar,
				.vgca-only-admin-content #adminmenumain,
				.vgca-only-admin-content #update-nag, 
				.vgca-only-admin-content .update-nag,
				.vgca-only-admin-content #wpfooter{
					display: none !important;
				}

				.vgca-only-admin-content .folded #wpcontent, 
				.vgca-only-admin-content .folded #wpfooter,
				.vgca-only-admin-content #wpcontent,
				.vgca-only-admin-content #wpfooter {
					margin-left: 0px !important;
					padding-left: 0px !important;
				}
				html.wp-toolbar.vgca-only-admin-content  {
					padding-top: 0px !important;
				}

			</style>
			<script>
				// Add the title to the "view in frontend" request
				jQuery(document).ready(function () {
					var $viewInFrontend = jQuery('.vgca-direct-frontend-link a');
					if ($viewInFrontend.length) {
						var slug = window.location.href.replace(window.location.origin, '').replace('/wp-admin/', '');
						$viewInFrontend.attr('href', $viewInFrontend.attr('href') + '&vgca_slug='+slug+'&title=' + jQuery('h1').first().text());
					}
				});
				if (parent.vgcaIsFrontendSession) {
					jQuery('html').addClass('vgca-only-admin-content');
					var customCss = <?php 
            echo  json_encode( $custom_css ) ;
            ?>;
					jQuery('head').append('<style id="vgca-custom-css">' + customCss + '</style>');

					// If URL is not for wp-admin page, open outside the iframe
					jQuery(document).ready(function () {
						jQuery('body').on('click', 'a', function (e) {
							var url = jQuery(this).attr('href');

							if (url.indexOf('/wp-admin') < 0 && url.indexOf('http') > -1) {
								top.window.location.href = url;
								e.preventDefault();
								return false;
							}
						});
					});
					jQuery(window).unload(function () {
						parent.$iframeWrappers.find('.vgca-loading-indicator').show();
						return null;
					});
					jQuery(window).load(function () {
						setTimeout(function () {
							parent.$iframeWrappers.find('.vgca-loading-indicator').hide();
						}, 500);
					});
				}

			</script>
			<?php 
        }
        
        function get_logout_link( $atts = array(), $content = '' )
        {
            extract( shortcode_atts( array(
                'page_url' => '',
            ), $atts ) );
            if ( !is_user_logged_in() ) {
                return;
            }
            $logout_link = str_replace( '<a ', '<a class="vg-logout-link" ', wp_loginout( $_SERVER['REQUEST_URI'], false ) );
            $out = '<style>.vg-logout-link{padding:5px;background:#000;color:#fff;text-decoration:none}</style>' . $logout_link;
            return $out;
        }
        
        function get_admin_page_for_frontend( $atts = array(), $content = '' )
        {
            extract( shortcode_atts( array(
                'page_url'           => '',
                'forward_parameters' => false,
            ), $atts ) );
            
            if ( !is_user_logged_in() ) {
                $login_message = $this->get_settings( 'login_message' );
                if ( !empty($login_message) ) {
                    $login_message = str_replace( array( '[vgca_login_page_link]' ), array( esc_url( wp_loginout( $_SERVER['REQUEST_URI'], false ) ) ), wp_kses_post( wpautop( $login_message ) ) );
                }
                $login_message .= wp_login_form( array(
                    'echo'     => false,
                    'redirect' => $_SERVER['REQUEST_URI'],
                ) );
                $out = '<style>.vg-frontend-admin-guests{text-align:center;margin-bottom:50px}.vg-frontend-admin-guests form{max-width:250px;margin:0 auto;text-align:left}.vg-frontend-admin-guests label{display:block}.vg-frontend-admin-guests form input[type=text],.vg-frontend-admin-guests form input[type=password],.vg-frontend-admin-guests form input[type=submit]{width:100%}.vg-frontend-admin-guests form input[type=submit]{padding:5px;border:0}</style><div class="vg-frontend-admin-guests">' . $login_message . '</div>';
                return $out;
            }
            
            if ( !$page_url ) {
                return;
            }
            if ( !empty($this->allowed_urls) && !in_array( $page_url, $this->allowed_urls ) ) {
                
                if ( is_super_admin() ) {
                    return sprintf( __( '<p>Admin page is not allowed to be displayed on the frontend</p>.<p>Please <a href="%s">open the settings page</a> to see the allowed URLs.', VG_Admin_To_Frontend::$textname ), admin_url( 'admin.php?page=wpatof_welcome_page' ) );
                } else {
                    return;
                }
            
            }
            ob_start();
            ?>

			<style>
				.vgca-iframe-wrapper iframe {
					width: 100%;
					min-width: 100%;
					max-width: 100%;
					height: 100%;
					position: absolute;
					border: 0px;
				}
				.vgca-iframe-wrapper {
					width: 100%;
					min-width: 100%;
					max-width: 100%;
					height: 100%;
					position: relative;	
					min-height: 80px;
				}
				.lds-ring {
					display: inline-block;
					position: relative;
					width: 64px;
					height: 64px;
				}
				.lds-ring div {
					box-sizing: border-box;
					display: block;
					position: absolute;
					width: 51px;
					height: 51px;
					margin: 6px;
					border: 6px solid #fff;
					border-radius: 50%;
					animation: lds-ring 1.2s cubic-bezier(0.5, 0, 0.5, 1) infinite;
					border-color: #fff transparent transparent transparent;
				}
				.lds-ring div:nth-child(1) {
					animation-delay: -0.45s;
				}
				.lds-ring div:nth-child(2) {
					animation-delay: -0.3s;
				}
				.lds-ring div:nth-child(3) {
					animation-delay: -0.15s;
				}
				@keyframes lds-ring {
					0% {
						transform: rotate(0deg);
					}
					100% {
						transform: rotate(360deg);
					}
				}
				.vgca-loading-indicator {
					/*display: block !important;*/
					background: #00000030;
					position: absolute;
					z-index: 9;
					left: 49%;
					border-radius: 50%;
				}

			</style>
			<div  class="vgca-iframe-wrapper">
				<!--Loading indicator-->
				<div class="lds-ring vgca-loading-indicator"><div></div><div></div><div></div><div></div></div>
				<iframe id="vgca-iframe-<?php 
            echo  crc32( $page_url ) ;
            ?>" data-forward-parameters="<?php 
            echo  (bool) $forward_parameters ;
            ?>"  src="<?php 
            $page_path_only = str_replace( array( admin_url(), '{{user_id}}' ), array( '', get_current_user_id() ), $page_url );
            if ( $forward_parameters ) {
                $page_path_only = add_query_arg( $_GET, $page_path_only );
            }
            echo  esc_url( admin_url( $page_path_only ) ) ;
            ?>"></iframe>
			</div>
			<script>
				window.vgcaIsFrontendSession = true;
				jQuery(window).load(function () {
					window.$iframeWrappers = jQuery('.vgca-iframe-wrapper ');
					$iframeWrappers.find('.vgca-loading-indicator').show();

					$iframeWrappers.each(function () {
						var $iframeWrapper = jQuery(this);
						var $iframe = $iframeWrapper.find('iframe');

						if ($iframe.data('forward-parameters')) {
							$iframe.attr('src', $iframe.attr('src') + window.location.hash);
						}

						$iframe.data('lastPage', $iframe.contents().get(0).location.href);
						setInterval(function () {
							var currentPage = $iframe.contents().get(0).location.href;

							// If the user navigated to another admin page, update the iframe height
							if (currentPage !== $iframe.data('lastPage')) {
								$iframeWrappers.css('height', '');
								$iframe.css('height', '');
								$iframe.data('lastPage', currentPage);
							}

							var iframeHeight = $iframe.contents().height();

			//							console.log('interval executed: ', iframeHeight, $iframe.height());
							$iframe.height(iframeHeight);
							$iframeWrapper.height(iframeHeight);
						}, 1000);
					});
				});
			</script>
			<?php 
            return ob_get_clean();
        }
        
        /**
         * Creates or returns an instance of this class.
         */
        static function get_instance()
        {
            
            if ( null == VG_Admin_To_Frontend::$instance ) {
                VG_Admin_To_Frontend::$instance = new VG_Admin_To_Frontend();
                VG_Admin_To_Frontend::$instance->init();
            }
            
            return VG_Admin_To_Frontend::$instance;
        }
        
        function __set( $name, $value )
        {
            $this->{$name} = $value;
        }
        
        function __get( $name )
        {
            return $this->{$name};
        }
    
    }
    if ( !function_exists( 'VG_Admin_To_Frontend_Obj' ) ) {
        function VG_Admin_To_Frontend_Obj()
        {
            return VG_Admin_To_Frontend::get_instance();
        }
    
    }
    VG_Admin_To_Frontend_Obj();
    require 'inc/options-init.php';
}
